/**
 * Job step to generate notifications.
 *
 * @module cartridge/scripts/jobs/createAlerts
 */

'use strict';

var Alerts = require('dw/alert/Alerts');
var Status = require('dw/system/Status');
var Site = require('dw/system/Site');
var Logger = require('dw/system/Logger').getLogger('BM-Alerts', 'alerts');

var noOrdersReceived = function(args) {
    try {
        // Check if any orders received in last 1hr.
        var OrderMgr = require('dw/order/OrderMgr');
        var timestamp = new Date((new Date().getTime() - (1 * 60 * 60 * 1000)));
        var orders = OrderMgr.queryOrders('creationDate > {0}', 'creationDate asc', timestamp);

		// Raise an alert if no orders received.
		if (orders.getCount() === 0) {
            Alerts.addAlert('no_orders_received', [Site.getCurrent().getID()]);
        } else {
            Alerts.removeAlert('no_orders_received');
        }
        return new Status(Status.OK);
    } catch (e) {
        Logger.error('Error while executing the script createAlerts.js~noOrdersReceived. Error...{0}', e.message);
        return new Status(Status.ERROR);
    }
};

var missingMandatoryCustomPreferences = function(args) {
    try {
        // Checking for mandatory custom preference - GoogleVerificationTag
        if (!(Site.getCurrent().getCustomPreferenceValue('GoogleVerificationTag'))) {
            Alerts.addAlert('missing_site_pref', Site.getCurrent().getPreferences(), ['GoogleVerificationTag']);
        } else {
            Alerts.removeAlert('missing_site_pref', Site.getCurrent().getPreferences());
        }
        return new Status(Status.OK);
    } catch (e) {
        Logger.error('Error while executing the script createAlerts.js~missingMandatoryCustomPreferences. Error...{0}', e.message);
        return new Status(Status.ERROR);
    }
};

/*Module exports*/
module.exports = {
    noOrdersReceived: noOrdersReceived,
    missingMandatoryCustomPreferences: missingMandatoryCustomPreferences
};
